{pkgs, ...}: {
  programs.hyprland = {
    enable = true;
    package = pkgs.unstable.hyprland;
  };

  hardware.opengl = {
    package = pkgs.unstable.mesa.drivers;
    package32 = pkgs.unstable.pkgsi686Linux.mesa.drivers;
  };

  services.gnome.gnome-keyring.enable = true;
  security.pam.services.greetd.enableGnomeKeyring = true;

  environment.systemPackages = with pkgs; [
    # Theme
    adw-gtk3

    # Applications
    gnome.nautilus
    gnome.sushi
    gnome.eog
    gnome.totem
    gnome.cheese
    gnome.file-roller
    gnome.gnome-weather
    gnome.gnome-contacts
    gnome.gnome-calendar
    gnome.gnome-screenshot
    gnome.gnome-dictionary
    gnome.gnome-font-viewer
    gnome.gnome-system-monitor
  ];

  # Required for Nautilus to work outside GNOME
  services.gvfs.enable = true;

  # Use CAPSLOCK as Hyper key
  services.keyd = {
    enable = true;
    keyboards.default = {
      ids = ["*"];
      settings.main = {
        capslock = "overload(meta, esc)";
      };
    };
  };

  services.greetd = {
    enable = true;
    settings = {
      default_session = {
        command = "${pkgs.greetd.tuigreet}/bin/tuigreet --time --cmd Hyprland";
        user = "greeter";
      };
    };
  };
}
